@@ -1,10 +1,11 @@
 "prod2COP" <-
 function(u,v, cop1=NULL, para1=NULL, cop2=NULL, para2=NULL,
-              para=NULL, interval=NULL, ...) {
+              para=NULL, pinterval=NULL, ...) {
 
    if(! is.null(para)) {
       cop1  <- para$cop1;    cop2  <- para$cop2
       para1 <- para$para1;   para2 <- para$para2
+      if(exists("pinterval", para)) pinterval <- get("pinterval", para)
    }
 
    if(is.null(cop1)) {
@@ -32,7 +33,7 @@ function(u,v, cop1=NULL, para1=NULL, cop2=NULL, para2=NULL,
    "afunc" <- function(t, U=NA, V=NA, ...) derCOP( t,V, cop=cop2, para=para2, ...) *
                                            derCOP2(U,t, cop=cop1, para=para1, ...)
    lo <- 0; hi <- 1
-   if(! is.null(interval)) { lo <- interval[1]; hi <- interval[2] }
+   if(! is.null(pinterval)) { lo <- pinterval[1]; hi <- pinterval[2] }
    return(sapply(1:length(u), function(i) integrate(afunc, lo,hi, U=u[i], V=v[i],
                            cop1=cop1, cop2=cop2, para1=para1, para2=para2, ...)$value))
 }
